@@ -27,6 +27,7 @@ __all__ = (
     "AttributeTypeDef",
     "CertificateInfoTypeDef",
     "CertificateTypeDef",
+    "ClientCertAuthSettingsTypeDef",
     "ComputerTypeDef",
     "ConditionalForwarderTypeDef",
     "DirectoryConnectSettingsDescriptionTypeDef",
@@ -107,6 +108,7 @@ CertificateInfoTypeDef = TypedDict(
             "DeregisterFailed",
         ],
         "ExpiryDateTime": datetime,
+        "Type": Literal["ClientCertAuth", "ClientLDAPS"],
     },
     total=False,
 )
@@ -127,10 +129,16 @@ CertificateTypeDef = TypedDict(
         "CommonName": str,
         "RegisteredDateTime": datetime,
         "ExpiryDateTime": datetime,
+        "Type": Literal["ClientCertAuth", "ClientLDAPS"],
+        "ClientCertAuthSettings": "ClientCertAuthSettingsTypeDef",
     },
     total=False,
 )
 
+ClientCertAuthSettingsTypeDef = TypedDict(
+    "ClientCertAuthSettingsTypeDef", {"OCSPUrl": str}, total=False
+)
+
 ComputerTypeDef = TypedDict(
     "ComputerTypeDef",
     {"ComputerId": str, "ComputerName": str, "ComputerAttributes": List["AttributeTypeDef"]},
